import React, { CSSProperties, FC } from 'react';
import { FormProps, RowProps } from 'antd';
export interface BitzQueryFilterPorps {
    onReset?: () => void;
    onFinish?: FormProps['onFinish'];
    children?: React.ReactNode;
    /**
     * 是否折叠超出的表单项，用于受控模式
     */
    collapsed?: boolean;
    /**
     * 切换表单折叠状态时的回调
     */
    onCollapse?: (collapsed: boolean) => void;
    style?: CSSProperties | undefined;
    /**
     * 默认状态下是否折叠超出的表单项
     */
    defaultCollapsed?: boolean;
    /**
     *layout 的布局设置
     * @type 'horizontal' | 'inline' | 'vertical';
     */
    layout?: FormProps['layout'];
    /**
     * 默认一行显示几个表单项
     */
    defaultColsNumber?: number;
    /**
     * 文字标签的宽度
     *
     * @example 文字标签宽 80 ，一般用于只有两个字
     * labelWidth={80}
     * @example 文字标签宽 140 ，一般用于有四个字
     * labelWidth={140}
     * @example 自动计算，会导致不整齐
     * labelWidth="auto"
     */
    labelWidth?: number | 'auto';
    /**
     * 配置列数，一般而言是 8 的倍数
     *
     * @example 配置一行4个
     * span={6}
     *
     * @example 配置一行3个
     * span={6}
     *
     * @example 根据屏幕宽度配置
     * span={xs: 24, sm: 12, md: 8, lg: 6, xl: 6, xxl: 6}
     * */
    span?: SpanConfig;
    /**
     * 忽略 Form.Item rule规则配置
     */
    ignoreRules?: boolean;
    /**
     * 是否显示 collapse 隐藏个数
     */
    showHiddenNum?: boolean;
    /**
     * 每一行之前要不要有分割线
     * @description 只有在 `layout` 为 `vertical` 时生效
     */
    split?: boolean;
    /**
     * 查询表单栅格间隔
     *
     * @example searchGutter={24}
     * */
    searchGutter?: RowProps['gutter'];
    /**
     * 是否能够查询收起的数据，如果设置为 false，收起后的表单数据将会丢失
     */
    preserve?: boolean;
}
export declare const colSpan: {
    xs: number;
    sm: number;
    md: number;
    lg: number;
    xl: number;
    xxl: number;
};
export type SpanConfig = number | {
    xs: number;
    sm: number;
    md: number;
    lg: number;
    xl: number;
    xxl: number;
};
declare const BitzQueryFilter: FC<BitzQueryFilterPorps>;
export default BitzQueryFilter;
