import { FC, ReactNode } from 'react';
import { BadgeProps } from 'antd';
import { IconNames } from '@/assets/iconfont';
import './index.less';
/** 图片tabbar属性 */
interface BitzTabbarItemImageConfig {
    /** 常规状态下的图片资源 */
    inactiveImage: string;
    /** 选中状态下的图片资源 */
    activeImage: string;
    /** 常规状态下的title文字颜色 */
    inactiveColor?: string | string[];
    /** 选中状态下的title文字颜色 */
    activeColor?: string | string[];
}
/** icon tabbar属性 */
interface BitzTabbarItemIconConfig {
    /** 常规状态下的icon */
    inactiveIcon: IconNames;
    /** 选中状态下的icon */
    activeIcon: IconNames;
    /** 常规状态下的title文字和icon颜色 */
    inactiveColor?: string | string[];
    /** 选中状态下的title文字和icon颜色 */
    activeColor?: string | string[];
}
/** 数字角标增强属性，新增zeroHidden，控制角标数字为0时是否显示角标 */
/**  Tabbar.Item属性 */
interface BitzTabbarItemProps {
    /** Tabbar.Item的唯一标识符（索引值或名称） */
    name: string | number;
    /** 图标/图片配置（选中和常规（未选中）状态的图标/图片/文字的样式） */
    config: BitzTabbarItemImageConfig | BitzTabbarItemIconConfig;
    /** Tabbar.Item的title */
    title?: string;
    /** Tabbar.Item的title，需要使用闭合标签（ReactNode版本） */
    children?: ReactNode;
    /** antd badge组件的基础props */
    badgeProps?: BadgeProps;
    /** （未开发）Tabbar在route模式下，路由跳转参数 */
    to?: string | object;
    /** （未开发）Tabbar在route模式下，路由跳转时是否关闭当前页面，并打开新页面 */
    replace?: boolean;
}
/** Tabbar.Item 父组件赋予的protected属性 */
export interface BitzTabbarItemProtectedProps {
    /** 当前Tabbar.Item的唯一标识符（索引值或名称） */
    currentName: string | number;
    /** Tabbar是否为route模式 */
    route?: boolean;
    /** BitzTabbar.Item的点击事件 */
    onClick: (name: string | number) => void;
}
/** Tabbar.Item Componet */
declare const BitzTabbarItem: FC<BitzTabbarItemProps>;
export default BitzTabbarItem;
