import { ReactNode, Ref } from 'react';
import { ProTableColumn } from '../Store';
export interface Action<T> {
    key?: string;
    icon?: ReactNode;
    label?: string;
    type?: 'divider' | 'group';
    onClick?: (record: T, index: number) => void;
    children?: Action<T>[];
}
export interface BitzTableActionProps<T> {
    loading?: boolean;
    /**
     * 操作按钮组，固定为主要操作、危险操作、次要操作
     * @次要操作 次要操作以下拉菜单显示，如果actionGroup的长度大于2，从第3个开始直到最后的所有按钮都为次要操作按钮
     */
    actionGroup: Action<T>[];
    refInstance?: Ref<HTMLDivElement>;
}
export declare function BitzTableAction<T>({ actionGroup, refInstance, }: BitzTableActionProps<T>): import("react/jsx-runtime").JSX.Element;
type withBitzTableActionProps<T> = Omit<BitzTableActionProps<T>, 'refInstance' | 'actionGroup'> & Omit<ProTableColumn<T>, 'width' | 'render'> & {
    actionGroup: Action<T>[] | ((record: T) => Action<T>[]);
};
/** 表格操作列 */
declare function BitzTableActionCol<T = any>(props: withBitzTableActionProps<T>): {
    fixed?: "left" | "right" | undefined;
    className?: string | undefined;
    order?: number | undefined;
    hidden?: boolean | undefined;
    ellipsis?: import("rc-table/lib/interface").CellEllipsisType | undefined;
    show?: boolean | undefined;
    title?: import("antd/es/table/interface").ColumnTitle<T>;
    key?: import("react").Key | undefined;
    align?: import("rc-table/lib/interface").AlignType | undefined;
    colSpan?: number | undefined;
    rowSpan?: number | undefined;
    dataIndex?: import("rc-table/lib/interface").DataIndex | undefined;
    shouldCellUpdate?: ((record: T, prevRecord: T) => boolean) | undefined;
    onCell?: import("rc-table/lib/interface").GetComponentProps<T> | undefined;
    onCellClick?: ((record: T, e: import("react").MouseEvent<HTMLElement, MouseEvent>) => void) | undefined;
    onHeaderCell?: import("rc-table/lib/interface").GetComponentProps<import("rc-table").ColumnType<T> | import("rc-table/lib/interface").ColumnGroupType<T>> | undefined;
    rowScope?: import("rc-table/lib/interface").RowScopeType | undefined;
    disable?: boolean | {
        checkbox: boolean;
    } | undefined;
    sortDirections?: import("antd/es/table/interface").SortOrder[] | undefined;
    showSorterTooltip?: boolean | import("antd").TooltipProps | undefined;
    sorter?: boolean | import("antd/es/table/interface").CompareFn<T> | {
        compare?: import("antd/es/table/interface").CompareFn<T> | undefined;
        multiple?: number | undefined;
    } | undefined;
    sortOrder?: import("antd/es/table/interface").SortOrder | undefined;
    defaultSortOrder?: import("antd/es/table/interface").SortOrder | undefined;
    sortIcon?: ((props: {
        sortOrder: import("antd/es/table/interface").SortOrder;
    }) => ReactNode) | undefined;
    filtered?: boolean | undefined;
    filters?: import("antd/es/table/interface").ColumnFilterItem[] | undefined;
    filterDropdown?: ReactNode | ((props: import("antd/es/table/interface").FilterDropdownProps) => ReactNode);
    filterMultiple?: boolean | undefined;
    filteredValue?: import("antd/es/table/interface").FilterValue | null | undefined;
    defaultFilteredValue?: import("antd/es/table/interface").FilterValue | null | undefined;
    filterIcon?: ReactNode | ((filtered: boolean) => ReactNode);
    filterMode?: "menu" | "tree" | undefined;
    filterSearch?: import("antd/es/table/interface").FilterSearchType<import("antd/es/table/interface").ColumnFilterItem> | undefined;
    onFilter?: ((value: boolean | import("react").Key, record: T) => boolean) | undefined;
    filterDropdownOpen?: boolean | undefined;
    onFilterDropdownOpenChange?: ((visible: boolean) => void) | undefined;
    filterResetToDefaultFilteredValue?: boolean | undefined;
    responsive?: import("antd").Breakpoint[] | undefined;
    filterDropdownVisible?: boolean | undefined;
    onFilterDropdownVisibleChange?: ((visible: boolean) => void) | undefined;
    width: number;
    render: (_: any, record: any, index: any) => import("react/jsx-runtime").JSX.Element;
};
export default BitzTableActionCol;
