import { ReactNode } from 'react';
import { TableProps } from 'antd';
import { SkeletonParagraphProps } from 'antd/es/skeleton/Paragraph';
import { AnyObject } from 'antd/es/_util/type';
import { ColumnStateType, DensitySize } from '../Store';
import { BitzTableColumnsType } from '..';
import './index.less';
export interface BitzTableProps<RecordType = any> extends Omit<TableProps<RecordType>, 'size' | 'pagination'> {
    /**
     * PC端：是否显示分页
     */
    showPagination?: boolean;
    /**
     * PC端&移动端：后端返回的数组数据
     */
    dataSource?: any[];
    /**
     * PC端：分页总数
     */
    total?: number;
    /**
     * PC端&移动端：自定义的列表参数
     */
    columns?: BitzTableColumnsType<RecordType>;
    /**
     * PC端&移动端：操作按钮数组
     */
    operations?: any;
    /**
     * PC&移动端：请求加载状态
     */
    loading?: boolean;
    /**
     * 骨架屏列表个数 移动端
     */
    skeletonNum?: number;
    /**
     * 骨架屏段落行数 移动端
     */
    skeletonRowNum?: SkeletonParagraphProps['rows'];
    /**
     * 骨架屏行宽度 移动端
     */
    skeletonRowsWidth?: SkeletonParagraphProps['width'];
    /**
     * 自定义骨架屏 移动端
     */
    skeletonRender?: () => ReactNode;
    /**
     * table布局size，默认为宽松(lg)
     */
    size?: DensitySize;
    /**
     * PC&移动端:操作按钮返回函数
     */
    tableOperationEmit?: (type: string, item: any) => void;
    /**
     * 是否启用分页组件的受控属性
     */
    enableControlPage?: boolean;
    /**
     * 分页控件的分页属性
     */
    pagination?: {
        page: number;
        size: number;
    };
    /**
     * PC端：给父组件传值 page当前第几页  pageSize每页有多少
     */
    paginationEmit?: (page: number, pageSize: number) => void;
    /**
     * 移动端：加载更多返回函数
     */
    mobileLoadEmit?: () => void;
    /**
     * 移动端：下拉刷新
     */
    mobileRefreshEmit?: () => void;
    /**
     * 移动端：列表数据回显
     */
    tableItemEmit?: (val: any) => void;
    /**
     * 移动端：页面高度，关系到上拉刷新
     */
    mobilePageHeight?: number;
    /**
     * 移动端：取消按钮名字
     */
    mobileCancelText?: string;
    /**
     * 移动端：暂无数据标题
     */
    noDataTitle?: string;
    /**
     * 移动端：图片，可以替换暂无数据的图片
     */
    noDataImg?: any;
    /**
     * 移动端：下拉刷新的颜色定义
     */
    color?: any;
    /**
     * 操作栏-左侧
     */
    tableAction?: ReactNode;
    /**
     * 操作栏-右侧
     */
    tableToolbar?: ReactNode;
    /**
     * 是否展示工具栏 默认为 true
     */
    showTableTool?: boolean;
    /**
     * 配置表格缓存 用于存储列配置
     * 为空不会缓存
     */
    columnsState?: ColumnStateType;
    /**
     * 重置分页的page为1
     */
    resetPage?: number;
}
declare const ProviderTableContainer: <T extends AnyObject>(props: BitzTableProps<T>) => import("react/jsx-runtime").JSX.Element;
export default ProviderTableContainer;
